Learn R Programming

etsi (version 1.0)

calculate.se: Estimates the standard error of the pooled treatment effect quantity.

Description

Estimates the standard error of the pooled treatment effect quantity.

Usage

calculate.se(y1.weak, y0.weak, y1.strong, y0.strong)

Value

Returns the estimated standard error.

Arguments

y1.weak

y1.weak, the primary outcome in the treatment group with weak surrogacy

y0.weak

y0.weak, the primary outcome in the control group with weak surrogacy

y1.strong

y1.strong, the predicted primary outcome given the surrogate in the treatment group with strong surrogacy

y0.strong

y0.strong, the predicted primary outcome given the surrogate in the control group with strong surrogacy