Learn R Programming

etsi (version 1.0)

check.strong.surr: Calculates whether each individual has a strong surrogate, based on PTE results from Study A and a desired threshold.

Description

Calculates whether each individual has a strong surrogate, based on PTE results from Study A and a desired threshold.

Usage

check.strong.surr(df, k, PTE.results)

Value

Returns a vector the same length as df, indicating for each row of df whether the surrogate is strong (1) or weak (0).

Arguments

df

The dataframe to determine strong surrogacy.

k

k, the threshold at which PTE > k qualifies as a strong surrogate

PTE.results

The PTE results (from the hetsurr::hetsurr.fun function) that should be used to determine strong surrogacy.